@@ -31,5 +31,5 @@ for i in names:
 score=score.sort_values(by=['score'])
 score.to_csv('result.csv',index=False)
 def main():
+ score=pd.read_csv('result.csv')
  print(score)
-main()
